@@ -143,13 +143,11 @@ func loadConfig(env platform.Environment) *Config {
 		cfg.Format = YAML
 		err = yaml.Unmarshal(data, &cfg)
 	case "jsonc", "json":
-		if cfg.Format == "jsonc" {
-			str := jsonutil.StripComments(string(data))
-			data = []byte(str)
-		}
-
 		cfg.Format = JSON
 
+		str := jsonutil.StripComments(string(data))
+		data = []byte(str)
+
 		decoder := json.NewDecoder(bytes.NewReader(data))
 		err = decoder.Decode(&cfg)
 	case "toml", "tml":
@@ -184,7 +182,7 @@ func (cfg *Config) Export(format string) string {
 			return ""
 		}
 
-		return prefix + escapeGlyphs(result.String(), cfg.MigrateGlyphs)
+		return prefix + result.String()
 	case JSON:
 		jsonEncoder := json.NewEncoder(&result)
 		jsonEncoder.SetEscapeHTML(false)
@@ -203,7 +201,7 @@ func (cfg *Config) Export(format string) string {
 			return ""
 		}
 
-		return prefix + escapeGlyphs(result.String(), cfg.MigrateGlyphs)
+		return prefix + result.String()
 	}
 
 	// unsupported format
